==> netgen_occt-0.0.1.dev0-py3-none-manylinux_2_17_x86_64.manylinux2014_x86_64.whl: netgen_occt-0.0.1.dev0.data/data/lib/cmake/opencascade/OpenCASCADEDataExchangeTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "TKDE" for configuration "Release"
set_property(TARGET TKDE APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(TKDE PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/./libTKDE.so.7.8.2"
  IMPORTED_SONAME_RELEASE "libTKDE.so.7.8.2"
  )

list(APPEND _cmake_import_check_targets TKDE )
list(APPEND _cmake_import_check_files_for_TKDE "${_IMPORT_PREFIX}/./libTKDE.so.7.8.2" )

# Import target "TKXSBase" for configuration "Release"
set_property(TARGET TKXSBase APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(TKXSBase PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/./libTKXSBase.so.7.8.2"
  IMPORTED_SONAME_RELEASE "libTKXSBase.so.7.8.2"
  )

list(APPEND _cmake_import_check_targets TKXSBase )
list(APPEND _cmake_import_check_files_for_TKXSBase "${_IMPORT_PREFIX}/./libTKXSBase.so.7.8.2" )

# Import target "TKDESTEP" for configuration "Release"
set_property(TARGET TKDESTEP APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(TKDESTEP PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/./libTKDESTEP.so.7.8.2"
  IMPORTED_SONAME_RELEASE "libTKDESTEP.so.7.8.2"
  )

list(APPEND _cmake_import_check_targets TKDESTEP )
list(APPEND _cmake_import_check_files_for_TKDESTEP "${_IMPORT_PREFIX}/./libTKDESTEP.so.7.8.2" )

# Import target "TKXCAF" for configuration "Release"
set_property(TARGET TKXCAF APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(TKXCAF PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/./libTKXCAF.so.7.8.2"
  IMPORTED_SONAME_RELEASE "libTKXCAF.so.7.8.2"
  )

list(APPEND _cmake_import_check_targets TKXCAF )
list(APPEND _cmake_import_check_files_for_TKXCAF "${_IMPORT_PREFIX}/./libTKXCAF.so.7.8.2" )

# Import target "TKDEIGES" for configuration "Release"
set_property(TARGET TKDEIGES APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(TKDEIGES PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/./libTKDEIGES.so.7.8.2"
  IMPORTED_SONAME_RELEASE "libTKDEIGES.so.7.8.2"
  )

list(APPEND _cmake_import_check_targets TKDEIGES )
list(APPEND _cmake_import_check_files_for_TKDEIGES "${_IMPORT_PREFIX}/./libTKDEIGES.so.7.8.2" )

# Import target "TKDESTL" for configuration "Release"
set_property(TARGET TKDESTL APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(TKDESTL PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/./libTKDESTL.so.7.8.2"
  IMPORTED_SONAME_RELEASE "libTKDESTL.so.7.8.2"
  )

list(APPEND _cmake_import_check_targets TKDESTL )
list(APPEND _cmake_import_check_files_for_TKDESTL "${_IMPORT_PREFIX}/./libTKDESTL.so.7.8.2" )

# Import target "TKDEVRML" for configuration "Release"
set_property(TARGET TKDEVRML APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(TKDEVRML PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/./libTKDEVRML.so.7.8.2"
  IMPORTED_SONAME_RELEASE "libTKDEVRML.so.7.8.2"
  )

list(APPEND _cmake_import_check_targets TKDEVRML )
list(APPEND _cmake_import_check_files_for_TKDEVRML "${_IMPORT_PREFIX}/./libTKDEVRML.so.7.8.2" )

# Import target "TKRWMesh" for configuration "Release"
set_property(TARGET TKRWMesh APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(TKRWMesh PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/./libTKRWMesh.so.7.8.2"
  IMPORTED_SONAME_RELEASE "libTKRWMesh.so.7.8.2"
  )

list(APPEND _cmake_import_check_targets TKRWMesh )
list(APPEND _cmake_import_check_files_for_TKRWMesh "${_IMPORT_PREFIX}/./libTKRWMesh.so.7.8.2" )

# Import target "TKDECascade" for configuration "Release"
set_property(TARGET TKDECascade APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(TKDECascade PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/./libTKDECascade.so.7.8.2"
  IMPORTED_SONAME_RELEASE "libTKDECascade.so.7.8.2"
  )

list(APPEND _cmake_import_check_targets TKDECascade )
list(APPEND _cmake_import_check_files_for_TKDECascade "${_IMPORT_PREFIX}/./libTKDECascade.so.7.8.2" )

# Import target "TKBinXCAF" for configuration "Release"
set_property(TARGET TKBinXCAF APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(TKBinXCAF PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/./libTKBinXCAF.so.7.8.2"
  IMPORTED_SONAME_RELEASE "libTKBinXCAF.so.7.8.2"
  )

list(APPEND _cmake_import_check_targets TKBinXCAF )
list(APPEND _cmake_import_check_files_for_TKBinXCAF "${_IMPORT_PREFIX}/./libTKBinXCAF.so.7.8.2" )

# Import target "TKXmlXCAF" for configuration "Release"
set_property(TARGET TKXmlXCAF APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(TKXmlXCAF PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/./libTKXmlXCAF.so.7.8.2"
  IMPORTED_SONAME_RELEASE "libTKXmlXCAF.so.7.8.2"
  )

list(APPEND _cmake_import_check_targets TKXmlXCAF )
list(APPEND _cmake_import_check_files_for_TKXmlXCAF "${_IMPORT_PREFIX}/./libTKXmlXCAF.so.7.8.2" )

# Import target "TKDEOBJ" for configuration "Release"
set_property(TARGET TKDEOBJ APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(TKDEOBJ PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/./libTKDEOBJ.so.7.8.2"
  IMPORTED_SONAME_RELEASE "libTKDEOBJ.so.7.8.2"
  )

list(APPEND _cmake_import_check_targets TKDEOBJ )
list(APPEND _cmake_import_check_files_for_TKDEOBJ "${_IMPORT_PREFIX}/./libTKDEOBJ.so.7.8.2" )

# Import target "TKDEGLTF" for configuration "Release"
set_property(TARGET TKDEGLTF APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(TKDEGLTF PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/./libTKDEGLTF.so.7.8.2"
  IMPORTED_SONAME_RELEASE "libTKDEGLTF.so.7.8.2"
  )

list(APPEND _cmake_import_check_targets TKDEGLTF )
list(APPEND _cmake_import_check_files_for_TKDEGLTF "${_IMPORT_PREFIX}/./libTKDEGLTF.so.7.8.2" )

# Import target "TKDEPLY" for configuration "Release"
set_property(TARGET TKDEPLY APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(TKDEPLY PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/./libTKDEPLY.so.7.8.2"
  IMPORTED_SONAME_RELEASE "libTKDEPLY.so.7.8.2"
  )

list(APPEND _cmake_import_check_targets TKDEPLY )
list(APPEND _cmake_import_check_files_for_TKDEPLY "${_IMPORT_PREFIX}/./libTKDEPLY.so.7.8.2" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> netgen_occt-0.0.5-py3-none-manylinux_2_17_x86_64.manylinux2014_x86_64.whl: netgen_occt-0.0.5.data/data/lib/cmake/opencascade/OpenCASCADEDataExchangeTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "TKDE" for configuration "Release"
set_property(TARGET TKDE APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(TKDE PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libTKDE.so.7.8.2"
  IMPORTED_SONAME_RELEASE "libTKDE.so.7.8.2"
  )

list(APPEND _cmake_import_check_targets TKDE )
list(APPEND _cmake_import_check_files_for_TKDE "${_IMPORT_PREFIX}/lib/libTKDE.so.7.8.2" )

# Import target "TKXSBase" for configuration "Release"
set_property(TARGET TKXSBase APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(TKXSBase PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libTKXSBase.so.7.8.2"
  IMPORTED_SONAME_RELEASE "libTKXSBase.so.7.8.2"
  )

list(APPEND _cmake_import_check_targets TKXSBase )
list(APPEND _cmake_import_check_files_for_TKXSBase "${_IMPORT_PREFIX}/lib/libTKXSBase.so.7.8.2" )

# Import target "TKDESTEP" for configuration "Release"
set_property(TARGET TKDESTEP APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(TKDESTEP PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libTKDESTEP.so.7.8.2"
  IMPORTED_SONAME_RELEASE "libTKDESTEP.so.7.8.2"
  )

list(APPEND _cmake_import_check_targets TKDESTEP )
list(APPEND _cmake_import_check_files_for_TKDESTEP "${_IMPORT_PREFIX}/lib/libTKDESTEP.so.7.8.2" )

# Import target "TKXCAF" for configuration "Release"
set_property(TARGET TKXCAF APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(TKXCAF PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libTKXCAF.so.7.8.2"
  IMPORTED_SONAME_RELEASE "libTKXCAF.so.7.8.2"
  )

list(APPEND _cmake_import_check_targets TKXCAF )
list(APPEND _cmake_import_check_files_for_TKXCAF "${_IMPORT_PREFIX}/lib/libTKXCAF.so.7.8.2" )

# Import target "TKDEIGES" for configuration "Release"
set_property(TARGET TKDEIGES APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(TKDEIGES PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libTKDEIGES.so.7.8.2"
  IMPORTED_SONAME_RELEASE "libTKDEIGES.so.7.8.2"
  )

list(APPEND _cmake_import_check_targets TKDEIGES )
list(APPEND _cmake_import_check_files_for_TKDEIGES "${_IMPORT_PREFIX}/lib/libTKDEIGES.so.7.8.2" )

# Import target "TKDESTL" for configuration "Release"
set_property(TARGET TKDESTL APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(TKDESTL PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libTKDESTL.so.7.8.2"
  IMPORTED_SONAME_RELEASE "libTKDESTL.so.7.8.2"
  )

list(APPEND _cmake_import_check_targets TKDESTL )
list(APPEND _cmake_import_check_files_for_TKDESTL "${_IMPORT_PREFIX}/lib/libTKDESTL.so.7.8.2" )

# Import target "TKDEVRML" for configuration "Release"
set_property(TARGET TKDEVRML APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(TKDEVRML PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libTKDEVRML.so.7.8.2"
  IMPORTED_SONAME_RELEASE "libTKDEVRML.so.7.8.2"
  )

list(APPEND _cmake_import_check_targets TKDEVRML )
list(APPEND _cmake_import_check_files_for_TKDEVRML "${_IMPORT_PREFIX}/lib/libTKDEVRML.so.7.8.2" )

# Import target "TKRWMesh" for configuration "Release"
set_property(TARGET TKRWMesh APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(TKRWMesh PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libTKRWMesh.so.7.8.2"
  IMPORTED_SONAME_RELEASE "libTKRWMesh.so.7.8.2"
  )

list(APPEND _cmake_import_check_targets TKRWMesh )
list(APPEND _cmake_import_check_files_for_TKRWMesh "${_IMPORT_PREFIX}/lib/libTKRWMesh.so.7.8.2" )

# Import target "TKDECascade" for configuration "Release"
set_property(TARGET TKDECascade APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(TKDECascade PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libTKDECascade.so.7.8.2"
  IMPORTED_SONAME_RELEASE "libTKDECascade.so.7.8.2"
  )

list(APPEND _cmake_import_check_targets TKDECascade )
list(APPEND _cmake_import_check_files_for_TKDECascade "${_IMPORT_PREFIX}/lib/libTKDECascade.so.7.8.2" )

# Import target "TKBinXCAF" for configuration "Release"
set_property(TARGET TKBinXCAF APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(TKBinXCAF PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libTKBinXCAF.so.7.8.2"
  IMPORTED_SONAME_RELEASE "libTKBinXCAF.so.7.8.2"
  )

list(APPEND _cmake_import_check_targets TKBinXCAF )
list(APPEND _cmake_import_check_files_for_TKBinXCAF "${_IMPORT_PREFIX}/lib/libTKBinXCAF.so.7.8.2" )

# Import target "TKXmlXCAF" for configuration "Release"
set_property(TARGET TKXmlXCAF APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(TKXmlXCAF PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libTKXmlXCAF.so.7.8.2"
  IMPORTED_SONAME_RELEASE "libTKXmlXCAF.so.7.8.2"
  )

list(APPEND _cmake_import_check_targets TKXmlXCAF )
list(APPEND _cmake_import_check_files_for_TKXmlXCAF "${_IMPORT_PREFIX}/lib/libTKXmlXCAF.so.7.8.2" )

# Import target "TKDEOBJ" for configuration "Release"
set_property(TARGET TKDEOBJ APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(TKDEOBJ PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libTKDEOBJ.so.7.8.2"
  IMPORTED_SONAME_RELEASE "libTKDEOBJ.so.7.8.2"
  )

list(APPEND _cmake_import_check_targets TKDEOBJ )
list(APPEND _cmake_import_check_files_for_TKDEOBJ "${_IMPORT_PREFIX}/lib/libTKDEOBJ.so.7.8.2" )

# Import target "TKDEGLTF" for configuration "Release"
set_property(TARGET TKDEGLTF APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(TKDEGLTF PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libTKDEGLTF.so.7.8.2"
  IMPORTED_SONAME_RELEASE "libTKDEGLTF.so.7.8.2"
  )

list(APPEND _cmake_import_check_targets TKDEGLTF )
list(APPEND _cmake_import_check_files_for_TKDEGLTF "${_IMPORT_PREFIX}/lib/libTKDEGLTF.so.7.8.2" )

# Import target "TKDEPLY" for configuration "Release"
set_property(TARGET TKDEPLY APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(TKDEPLY PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libTKDEPLY.so.7.8.2"
  IMPORTED_SONAME_RELEASE "libTKDEPLY.so.7.8.2"
  )

list(APPEND _cmake_import_check_targets TKDEPLY )
list(APPEND _cmake_import_check_files_for_TKDEPLY "${_IMPORT_PREFIX}/lib/libTKDEPLY.so.7.8.2" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
